![alt text](https://github.com/Benedict-Carling/platemap/blob/main/docs/static/img/greenlogo.svg)

[![Pytest](https://github.com/Benedict-Carling/platemap/actions/workflows/pytest.yml/badge.svg)](https://github.com/Benedict-Carling/platemap/actions/workflows/pytest.yml)
[![Coverage Status](https://coveralls.io/repos/github/Benedict-Carling/platemap/badge.svg?branch=main)](https://coveralls.io/github/Benedict-Carling/platemap?branch=main)
![PyPI](https://img.shields.io/pypi/v/platemap?color=green)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

A small and simple class to handle microplate's / micro titreplate's within python

## Documentation

Documentation, Usage and Contributing Guidlines are hosted at [platemap](https://platemap.vercel.app)

## Installation

To install platemap from pypi

```bash
$ pip install platemap
```

To install from github

```bash
$ git clone https://github.com/Benedict-Carling/platemap.git
```

```bash
cd platemap
```

```bash
python setup.py install
```
